# Important

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**context_path** | **str** |  | [optional] 
**description** | **str** | Description is either a string or a map from string to interface | [optional] 
**related** | **str** | To what other context path this output is related | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


